/**
 * Detect the use of any of a given list of CSS features.
 * ```
 * var detector = new Detector(featureList)
 * detector.process(css, cb)
 * ```
 *
 * `featureList`: an array of feature slugs (see caniuse-db)
 * `cb`: a callback that gets called for each usage of one of the given features,
 * called with an argument like:
 * ```
 * {
 *   usage: {} // postcss node where usage was found
 *   feature: {} // caniuse-db feature slug
 *   ignore: {} // caniuse-db feature to ignore in current file
 * }
 * ```
 */
export default class Detector {
    /**
     * @param {(keyof FEATURES & string)[]} featureList an array of feature slugs (see caniuse-db)
     */
    constructor(featureList: (keyof {
        outline: import("../data/features.js").Feature;
        "background-attachment": import("../data/features.js").Feature;
        pointer: import("../data/features.js").Feature;
        "flow-root": import("../data/features.js").Feature;
        "font-kerning": import("../data/features.js").Feature;
        "font-smooth": import("../data/features.js").Feature;
        "font-variant-alternates": import("../data/features.js").Feature;
        "font-variant-numeric": import("../data/features.js").Feature;
        "inline-block": import("../data/features.js").Feature;
        "prefers-color-scheme": import("../data/features.js").Feature;
        "prefers-reduced-motion": import("../data/features.js").Feature;
        rem: import("../data/features.js").Feature;
        "run-in": import("../data/features.js").Feature;
        "text-emphasis": import("../data/features.js").Feature;
        "text-stroke": import("../data/features.js").Feature;
        "webkit-user-drag": import("../data/features.js").Feature;
        "border-image": import("../data/features.js").Feature;
        "border-radius": import("../data/features.js").Feature;
        "font-size-adjust": import("../data/features.js").Feature;
        "text-decoration": import("../data/features.js").Feature;
        "object-fit": import("../data/features.js").Feature;
        "pointer-events": import("../data/features.js").Feature;
        "text-overflow": import("../data/features.js").Feature;
        "text-size-adjust": import("../data/features.js").Feature;
        "will-change": import("../data/features.js").Feature;
        "word-break": import("../data/features.js").Feature;
        "alternate-stylesheet": import("../data/features.js").Feature;
        "background-clip-text": import("../data/features.js").Feature;
        "background-img-opts": import("../data/features.js").Feature;
        "background-position-x-y": import("../data/features.js").Feature;
        "background-repeat-round-space": import("../data/features.js").Feature;
        calc: import("../data/features.js").Feature;
        "ch-unit": import("../data/features.js").Feature;
        "css-all": import("../data/features.js").Feature;
        "css-animation": import("../data/features.js").Feature;
        "css-any-link": import("../data/features.js").Feature;
        "css-appearance": import("../data/features.js").Feature;
        "css-at-counter-style": import("../data/features.js").Feature;
        "css-autofill": import("../data/features.js").Feature;
        "css-backdrop-filter": import("../data/features.js").Feature;
        "css-background-offsets": import("../data/features.js").Feature;
        "css-backgroundblendmode": import("../data/features.js").Feature;
        "css-boxdecorationbreak": import("../data/features.js").Feature;
        "css-boxshadow": import("../data/features.js").Feature;
        "css-canvas": import("../data/features.js").Feature;
        "css-caret-color": import("../data/features.js").Feature;
        "css-cascade-layers": import("../data/features.js").Feature;
        "css-case-insensitive": import("../data/features.js").Feature;
        "css-clip-path": import("../data/features.js").Feature;
        "css-color-adjust": import("../data/features.js").Feature;
        "css-color-function": import("../data/features.js").Feature;
        "css-conic-gradients": import("../data/features.js").Feature;
        "css-container-queries": import("../data/features.js").Feature;
        "css-container-queries-style": import("../data/features.js").Feature;
        "css-container-query-units": import("../data/features.js").Feature;
        "css-containment": import("../data/features.js").Feature;
        "css-content-visibility": import("../data/features.js").Feature;
        "css-counters": import("../data/features.js").Feature;
        "css-crisp-edges": import("../data/features.js").Feature;
        "css-cross-fade": import("../data/features.js").Feature;
        "css-default-pseudo": import("../data/features.js").Feature;
        "css-descendant-gtgt": import("../data/features.js").Feature;
        "css-deviceadaptation": import("../data/features.js").Feature;
        "css-dir-pseudo": import("../data/features.js").Feature;
        "css-display-contents": import("../data/features.js").Feature;
        "css-element-function": import("../data/features.js").Feature;
        "css-env-function": import("../data/features.js").Feature;
        "css-exclusions": import("../data/features.js").Feature;
        "css-featurequeries": import("../data/features.js").Feature;
        "css-file-selector-button": import("../data/features.js").Feature;
        "css-filter-function": import("../data/features.js").Feature;
        "css-filters": import("../data/features.js").Feature;
        "css-first-letter": import("../data/features.js").Feature;
        "css-first-line": import("../data/features.js").Feature;
        "css-fixed": import("../data/features.js").Feature;
        "css-focus-visible": import("../data/features.js").Feature;
        "css-focus-within": import("../data/features.js").Feature;
        "css-font-palette": import("../data/features.js").Feature;
        "css-font-rendering-controls": import("../data/features.js").Feature;
        "css-font-stretch": import("../data/features.js").Feature;
        "css-gencontent": import("../data/features.js").Feature;
        "css-gradients": import("../data/features.js").Feature;
        "css-grid": import("../data/features.js").Feature;
        "css-grid-animation": import("../data/features.js").Feature;
        "css-hanging-punctuation": import("../data/features.js").Feature;
        "css-has": import("../data/features.js").Feature;
        "css-hyphens": import("../data/features.js").Feature;
        "css-image-orientation": import("../data/features.js").Feature;
        "css-image-set": import("../data/features.js").Feature;
        "css-in-out-of-range": import("../data/features.js").Feature;
        "css-indeterminate-pseudo": import("../data/features.js").Feature;
        "css-initial-letter": import("../data/features.js").Feature;
        "css-initial-value": import("../data/features.js").Feature;
        "css-lch-lab": import("../data/features.js").Feature;
        "css-letter-spacing": import("../data/features.js").Feature;
        "css-line-clamp": import("../data/features.js").Feature;
        "css-logical-props": import("../data/features.js").Feature;
        "css-marker-pseudo": import("../data/features.js").Feature;
        "css-masks": import("../data/features.js").Feature;
        "css-matches-pseudo": import("../data/features.js").Feature;
        "css-math-functions": import("../data/features.js").Feature;
        "css-media-interaction": import("../data/features.js").Feature;
        "css-media-range-syntax": import("../data/features.js").Feature;
        "css-media-resolution": import("../data/features.js").Feature;
        "css-media-scripting": import("../data/features.js").Feature;
        "css-mediaqueries": import("../data/features.js").Feature;
        "css-mixblendmode": import("../data/features.js").Feature;
        "css-motion-paths": import("../data/features.js").Feature;
        "css-namespaces": import("../data/features.js").Feature;
        "css-nesting": import("../data/features.js").Feature;
        "css-not-sel-list": import("../data/features.js").Feature;
        "css-nth-child-of": import("../data/features.js").Feature;
        "css-opacity": import("../data/features.js").Feature;
        "css-optional-pseudo": import("../data/features.js").Feature;
        "css-overflow": import("../data/features.js").Feature;
        "css-overflow-anchor": import("../data/features.js").Feature;
        "css-overflow-overlay": import("../data/features.js").Feature;
        "css-overscroll-behavior": import("../data/features.js").Feature;
        "css-page-break": import("../data/features.js").Feature;
        "css-paged-media": import("../data/features.js").Feature;
        "css-paint-api": import("../data/features.js").Feature;
        "css-placeholder": import("../data/features.js").Feature;
        "css-placeholder-shown": import("../data/features.js").Feature;
        "css-print-color-adjust": import("../data/features.js").Feature;
        "css-read-only-write": import("../data/features.js").Feature;
        "css-rebeccapurple": import("../data/features.js").Feature;
        "css-reflections": import("../data/features.js").Feature;
        "css-regions": import("../data/features.js").Feature;
        "css-relative-colors": import("../data/features.js").Feature;
        "css-repeating-gradients": import("../data/features.js").Feature;
        "css-resize": import("../data/features.js").Feature;
        "css-revert-value": import("../data/features.js").Feature;
        "css-rrggbbaa": import("../data/features.js").Feature;
        "css-scroll-behavior": import("../data/features.js").Feature;
        "css-scroll-timeline": import("../data/features.js").Feature;
        "css-scrollbar": import("../data/features.js").Feature;
        "css-sel2": import("../data/features.js").Feature;
        "css-sel3": import("../data/features.js").Feature;
        "css-selection": import("../data/features.js").Feature;
        "css-shapes": import("../data/features.js").Feature;
        "css-snappoints": import("../data/features.js").Feature;
        "css-sticky": import("../data/features.js").Feature;
        "css-subgrid": import("../data/features.js").Feature;
        "css-supports-api": import("../data/features.js").Feature;
        "css-table": import("../data/features.js").Feature;
        "css-text-align-last": import("../data/features.js").Feature;
        "css-text-box-trim": import("../data/features.js").Feature;
        "css-text-indent": import("../data/features.js").Feature;
        "css-text-justify": import("../data/features.js").Feature;
        "css-text-orientation": import("../data/features.js").Feature;
        "css-text-spacing": import("../data/features.js").Feature;
        "css-textshadow": import("../data/features.js").Feature;
        "css-touch-action": import("../data/features.js").Feature;
        "css-transitions": import("../data/features.js").Feature;
        "css-unicode-bidi": import("../data/features.js").Feature;
        "css-unset-value": import("../data/features.js").Feature;
        "css-variables": import("../data/features.js").Feature;
        "css-when-else": import("../data/features.js").Feature;
        "css-widows-orphans": import("../data/features.js").Feature;
        "css-width-stretch": import("../data/features.js").Feature;
        "css-writing-mode": import("../data/features.js").Feature;
        "css-zoom": import("../data/features.js").Feature;
        "css3-attr": import("../data/features.js").Feature;
        "css3-boxsizing": import("../data/features.js").Feature;
        "css3-colors": import("../data/features.js").Feature;
        "css3-cursors": import("../data/features.js").Feature;
        "css3-cursors-grab": import("../data/features.js").Feature;
        "css3-cursors-newer": import("../data/features.js").Feature;
        "css3-tabsize": import("../data/features.js").Feature;
        currentcolor: import("../data/features.js").Feature;
        devicepixelratio: import("../data/features.js").Feature;
        "extended-system-fonts": import("../data/features.js").Feature;
        flexbox: import("../data/features.js").Feature;
        "flexbox-gap": import("../data/features.js").Feature;
        "font-family-system-ui": import("../data/features.js").Feature;
        "font-feature": import("../data/features.js").Feature;
        "font-loading": import("../data/features.js").Feature;
        "font-unicode-range": import("../data/features.js").Feature;
        fontface: import("../data/features.js").Feature;
        fullscreen: import("../data/features.js").Feature;
        getcomputedstyle: import("../data/features.js").Feature;
        "intrinsic-width": import("../data/features.js").Feature;
        "justify-content-space-evenly": import("../data/features.js").Feature;
        "kerning-pairs-ligatures": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate-override": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-plaintext": import("../data/features.js").Feature;
        "mdn-text-decoration-color": import("../data/features.js").Feature;
        "mdn-text-decoration-line": import("../data/features.js").Feature;
        "mdn-text-decoration-shorthand": import("../data/features.js").Feature;
        "mdn-text-decoration-style": import("../data/features.js").Feature;
        minmaxwh: import("../data/features.js").Feature;
        multibackgrounds: import("../data/features.js").Feature;
        multicolumn: import("../data/features.js").Feature;
        "style-scoped": import("../data/features.js").Feature;
        "svg-css": import("../data/features.js").Feature;
        transforms2d: import("../data/features.js").Feature;
        transforms3d: import("../data/features.js").Feature;
        ttf: import("../data/features.js").Feature;
        "user-select-none": import("../data/features.js").Feature;
        "variable-fonts": import("../data/features.js").Feature;
        "viewport-unit-variants": import("../data/features.js").Feature;
        "viewport-units": import("../data/features.js").Feature;
        wordwrap: import("../data/features.js").Feature;
    } & string)[]);
    /** @type {Partial<FEATURES>} */
    features: Partial<{
        outline: import("../data/features.js").Feature;
        "background-attachment": import("../data/features.js").Feature;
        pointer: import("../data/features.js").Feature;
        "flow-root": import("../data/features.js").Feature;
        "font-kerning": import("../data/features.js").Feature;
        "font-smooth": import("../data/features.js").Feature;
        "font-variant-alternates": import("../data/features.js").Feature;
        "font-variant-numeric": import("../data/features.js").Feature;
        "inline-block": import("../data/features.js").Feature;
        "prefers-color-scheme": import("../data/features.js").Feature;
        "prefers-reduced-motion": import("../data/features.js").Feature;
        rem: import("../data/features.js").Feature;
        "run-in": import("../data/features.js").Feature;
        "text-emphasis": import("../data/features.js").Feature;
        "text-stroke": import("../data/features.js").Feature;
        "webkit-user-drag": import("../data/features.js").Feature;
        "border-image": import("../data/features.js").Feature;
        "border-radius": import("../data/features.js").Feature;
        "font-size-adjust": import("../data/features.js").Feature;
        "text-decoration": import("../data/features.js").Feature;
        "object-fit": import("../data/features.js").Feature;
        "pointer-events": import("../data/features.js").Feature;
        "text-overflow": import("../data/features.js").Feature;
        "text-size-adjust": import("../data/features.js").Feature;
        "will-change": import("../data/features.js").Feature;
        "word-break": import("../data/features.js").Feature;
        "alternate-stylesheet": import("../data/features.js").Feature;
        "background-clip-text": import("../data/features.js").Feature;
        "background-img-opts": import("../data/features.js").Feature;
        "background-position-x-y": import("../data/features.js").Feature;
        "background-repeat-round-space": import("../data/features.js").Feature;
        calc: import("../data/features.js").Feature;
        "ch-unit": import("../data/features.js").Feature;
        "css-all": import("../data/features.js").Feature;
        "css-animation": import("../data/features.js").Feature;
        "css-any-link": import("../data/features.js").Feature;
        "css-appearance": import("../data/features.js").Feature;
        "css-at-counter-style": import("../data/features.js").Feature;
        "css-autofill": import("../data/features.js").Feature;
        "css-backdrop-filter": import("../data/features.js").Feature;
        "css-background-offsets": import("../data/features.js").Feature;
        "css-backgroundblendmode": import("../data/features.js").Feature;
        "css-boxdecorationbreak": import("../data/features.js").Feature;
        "css-boxshadow": import("../data/features.js").Feature;
        "css-canvas": import("../data/features.js").Feature;
        "css-caret-color": import("../data/features.js").Feature;
        "css-cascade-layers": import("../data/features.js").Feature;
        "css-case-insensitive": import("../data/features.js").Feature;
        "css-clip-path": import("../data/features.js").Feature;
        "css-color-adjust": import("../data/features.js").Feature;
        "css-color-function": import("../data/features.js").Feature;
        "css-conic-gradients": import("../data/features.js").Feature;
        "css-container-queries": import("../data/features.js").Feature;
        "css-container-queries-style": import("../data/features.js").Feature;
        "css-container-query-units": import("../data/features.js").Feature;
        "css-containment": import("../data/features.js").Feature;
        "css-content-visibility": import("../data/features.js").Feature;
        "css-counters": import("../data/features.js").Feature;
        "css-crisp-edges": import("../data/features.js").Feature;
        "css-cross-fade": import("../data/features.js").Feature;
        "css-default-pseudo": import("../data/features.js").Feature;
        "css-descendant-gtgt": import("../data/features.js").Feature;
        "css-deviceadaptation": import("../data/features.js").Feature;
        "css-dir-pseudo": import("../data/features.js").Feature;
        "css-display-contents": import("../data/features.js").Feature;
        "css-element-function": import("../data/features.js").Feature;
        "css-env-function": import("../data/features.js").Feature;
        "css-exclusions": import("../data/features.js").Feature;
        "css-featurequeries": import("../data/features.js").Feature;
        "css-file-selector-button": import("../data/features.js").Feature;
        "css-filter-function": import("../data/features.js").Feature;
        "css-filters": import("../data/features.js").Feature;
        "css-first-letter": import("../data/features.js").Feature;
        "css-first-line": import("../data/features.js").Feature;
        "css-fixed": import("../data/features.js").Feature;
        "css-focus-visible": import("../data/features.js").Feature;
        "css-focus-within": import("../data/features.js").Feature;
        "css-font-palette": import("../data/features.js").Feature;
        "css-font-rendering-controls": import("../data/features.js").Feature;
        "css-font-stretch": import("../data/features.js").Feature;
        "css-gencontent": import("../data/features.js").Feature;
        "css-gradients": import("../data/features.js").Feature;
        "css-grid": import("../data/features.js").Feature;
        "css-grid-animation": import("../data/features.js").Feature;
        "css-hanging-punctuation": import("../data/features.js").Feature;
        "css-has": import("../data/features.js").Feature;
        "css-hyphens": import("../data/features.js").Feature;
        "css-image-orientation": import("../data/features.js").Feature;
        "css-image-set": import("../data/features.js").Feature;
        "css-in-out-of-range": import("../data/features.js").Feature;
        "css-indeterminate-pseudo": import("../data/features.js").Feature;
        "css-initial-letter": import("../data/features.js").Feature;
        "css-initial-value": import("../data/features.js").Feature;
        "css-lch-lab": import("../data/features.js").Feature;
        "css-letter-spacing": import("../data/features.js").Feature;
        "css-line-clamp": import("../data/features.js").Feature;
        "css-logical-props": import("../data/features.js").Feature;
        "css-marker-pseudo": import("../data/features.js").Feature;
        "css-masks": import("../data/features.js").Feature;
        "css-matches-pseudo": import("../data/features.js").Feature;
        "css-math-functions": import("../data/features.js").Feature;
        "css-media-interaction": import("../data/features.js").Feature;
        "css-media-range-syntax": import("../data/features.js").Feature;
        "css-media-resolution": import("../data/features.js").Feature;
        "css-media-scripting": import("../data/features.js").Feature;
        "css-mediaqueries": import("../data/features.js").Feature;
        "css-mixblendmode": import("../data/features.js").Feature;
        "css-motion-paths": import("../data/features.js").Feature;
        "css-namespaces": import("../data/features.js").Feature;
        "css-nesting": import("../data/features.js").Feature;
        "css-not-sel-list": import("../data/features.js").Feature;
        "css-nth-child-of": import("../data/features.js").Feature;
        "css-opacity": import("../data/features.js").Feature;
        "css-optional-pseudo": import("../data/features.js").Feature;
        "css-overflow": import("../data/features.js").Feature;
        "css-overflow-anchor": import("../data/features.js").Feature;
        "css-overflow-overlay": import("../data/features.js").Feature;
        "css-overscroll-behavior": import("../data/features.js").Feature;
        "css-page-break": import("../data/features.js").Feature;
        "css-paged-media": import("../data/features.js").Feature;
        "css-paint-api": import("../data/features.js").Feature;
        "css-placeholder": import("../data/features.js").Feature;
        "css-placeholder-shown": import("../data/features.js").Feature;
        "css-print-color-adjust": import("../data/features.js").Feature;
        "css-read-only-write": import("../data/features.js").Feature;
        "css-rebeccapurple": import("../data/features.js").Feature;
        "css-reflections": import("../data/features.js").Feature;
        "css-regions": import("../data/features.js").Feature;
        "css-relative-colors": import("../data/features.js").Feature;
        "css-repeating-gradients": import("../data/features.js").Feature;
        "css-resize": import("../data/features.js").Feature;
        "css-revert-value": import("../data/features.js").Feature;
        "css-rrggbbaa": import("../data/features.js").Feature;
        "css-scroll-behavior": import("../data/features.js").Feature;
        "css-scroll-timeline": import("../data/features.js").Feature;
        "css-scrollbar": import("../data/features.js").Feature;
        "css-sel2": import("../data/features.js").Feature;
        "css-sel3": import("../data/features.js").Feature;
        "css-selection": import("../data/features.js").Feature;
        "css-shapes": import("../data/features.js").Feature;
        "css-snappoints": import("../data/features.js").Feature;
        "css-sticky": import("../data/features.js").Feature;
        "css-subgrid": import("../data/features.js").Feature;
        "css-supports-api": import("../data/features.js").Feature;
        "css-table": import("../data/features.js").Feature;
        "css-text-align-last": import("../data/features.js").Feature;
        "css-text-box-trim": import("../data/features.js").Feature;
        "css-text-indent": import("../data/features.js").Feature;
        "css-text-justify": import("../data/features.js").Feature;
        "css-text-orientation": import("../data/features.js").Feature;
        "css-text-spacing": import("../data/features.js").Feature;
        "css-textshadow": import("../data/features.js").Feature;
        "css-touch-action": import("../data/features.js").Feature;
        "css-transitions": import("../data/features.js").Feature;
        "css-unicode-bidi": import("../data/features.js").Feature;
        "css-unset-value": import("../data/features.js").Feature;
        "css-variables": import("../data/features.js").Feature;
        "css-when-else": import("../data/features.js").Feature;
        "css-widows-orphans": import("../data/features.js").Feature;
        "css-width-stretch": import("../data/features.js").Feature;
        "css-writing-mode": import("../data/features.js").Feature;
        "css-zoom": import("../data/features.js").Feature;
        "css3-attr": import("../data/features.js").Feature;
        "css3-boxsizing": import("../data/features.js").Feature;
        "css3-colors": import("../data/features.js").Feature;
        "css3-cursors": import("../data/features.js").Feature;
        "css3-cursors-grab": import("../data/features.js").Feature;
        "css3-cursors-newer": import("../data/features.js").Feature;
        "css3-tabsize": import("../data/features.js").Feature;
        currentcolor: import("../data/features.js").Feature;
        devicepixelratio: import("../data/features.js").Feature;
        "extended-system-fonts": import("../data/features.js").Feature;
        flexbox: import("../data/features.js").Feature;
        "flexbox-gap": import("../data/features.js").Feature;
        "font-family-system-ui": import("../data/features.js").Feature;
        "font-feature": import("../data/features.js").Feature;
        "font-loading": import("../data/features.js").Feature;
        "font-unicode-range": import("../data/features.js").Feature;
        fontface: import("../data/features.js").Feature;
        fullscreen: import("../data/features.js").Feature;
        getcomputedstyle: import("../data/features.js").Feature;
        "intrinsic-width": import("../data/features.js").Feature;
        "justify-content-space-evenly": import("../data/features.js").Feature;
        "kerning-pairs-ligatures": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate-override": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-plaintext": import("../data/features.js").Feature;
        "mdn-text-decoration-color": import("../data/features.js").Feature;
        "mdn-text-decoration-line": import("../data/features.js").Feature;
        "mdn-text-decoration-shorthand": import("../data/features.js").Feature;
        "mdn-text-decoration-style": import("../data/features.js").Feature;
        minmaxwh: import("../data/features.js").Feature;
        multibackgrounds: import("../data/features.js").Feature;
        multicolumn: import("../data/features.js").Feature;
        "style-scoped": import("../data/features.js").Feature;
        "svg-css": import("../data/features.js").Feature;
        transforms2d: import("../data/features.js").Feature;
        transforms3d: import("../data/features.js").Feature;
        ttf: import("../data/features.js").Feature;
        "user-select-none": import("../data/features.js").Feature;
        "variable-fonts": import("../data/features.js").Feature;
        "viewport-unit-variants": import("../data/features.js").Feature;
        "viewport-units": import("../data/features.js").Feature;
        wordwrap: import("../data/features.js").Feature;
    }>;
    /** @type {(keyof FEATURES & string)[]} */
    ignore: (keyof {
        outline: import("../data/features.js").Feature;
        "background-attachment": import("../data/features.js").Feature;
        pointer: import("../data/features.js").Feature;
        "flow-root": import("../data/features.js").Feature;
        "font-kerning": import("../data/features.js").Feature;
        "font-smooth": import("../data/features.js").Feature;
        "font-variant-alternates": import("../data/features.js").Feature;
        "font-variant-numeric": import("../data/features.js").Feature;
        "inline-block": import("../data/features.js").Feature;
        "prefers-color-scheme": import("../data/features.js").Feature;
        "prefers-reduced-motion": import("../data/features.js").Feature;
        rem: import("../data/features.js").Feature;
        "run-in": import("../data/features.js").Feature;
        "text-emphasis": import("../data/features.js").Feature;
        "text-stroke": import("../data/features.js").Feature;
        "webkit-user-drag": import("../data/features.js").Feature;
        "border-image": import("../data/features.js").Feature;
        "border-radius": import("../data/features.js").Feature;
        "font-size-adjust": import("../data/features.js").Feature;
        "text-decoration": import("../data/features.js").Feature;
        "object-fit": import("../data/features.js").Feature;
        "pointer-events": import("../data/features.js").Feature;
        "text-overflow": import("../data/features.js").Feature;
        "text-size-adjust": import("../data/features.js").Feature;
        "will-change": import("../data/features.js").Feature;
        "word-break": import("../data/features.js").Feature;
        "alternate-stylesheet": import("../data/features.js").Feature;
        "background-clip-text": import("../data/features.js").Feature;
        "background-img-opts": import("../data/features.js").Feature;
        "background-position-x-y": import("../data/features.js").Feature;
        "background-repeat-round-space": import("../data/features.js").Feature;
        calc: import("../data/features.js").Feature;
        "ch-unit": import("../data/features.js").Feature;
        "css-all": import("../data/features.js").Feature;
        "css-animation": import("../data/features.js").Feature;
        "css-any-link": import("../data/features.js").Feature;
        "css-appearance": import("../data/features.js").Feature;
        "css-at-counter-style": import("../data/features.js").Feature;
        "css-autofill": import("../data/features.js").Feature;
        "css-backdrop-filter": import("../data/features.js").Feature;
        "css-background-offsets": import("../data/features.js").Feature;
        "css-backgroundblendmode": import("../data/features.js").Feature;
        "css-boxdecorationbreak": import("../data/features.js").Feature;
        "css-boxshadow": import("../data/features.js").Feature;
        "css-canvas": import("../data/features.js").Feature;
        "css-caret-color": import("../data/features.js").Feature;
        "css-cascade-layers": import("../data/features.js").Feature;
        "css-case-insensitive": import("../data/features.js").Feature;
        "css-clip-path": import("../data/features.js").Feature;
        "css-color-adjust": import("../data/features.js").Feature;
        "css-color-function": import("../data/features.js").Feature;
        "css-conic-gradients": import("../data/features.js").Feature;
        "css-container-queries": import("../data/features.js").Feature;
        "css-container-queries-style": import("../data/features.js").Feature;
        "css-container-query-units": import("../data/features.js").Feature;
        "css-containment": import("../data/features.js").Feature;
        "css-content-visibility": import("../data/features.js").Feature;
        "css-counters": import("../data/features.js").Feature;
        "css-crisp-edges": import("../data/features.js").Feature;
        "css-cross-fade": import("../data/features.js").Feature;
        "css-default-pseudo": import("../data/features.js").Feature;
        "css-descendant-gtgt": import("../data/features.js").Feature;
        "css-deviceadaptation": import("../data/features.js").Feature;
        "css-dir-pseudo": import("../data/features.js").Feature;
        "css-display-contents": import("../data/features.js").Feature;
        "css-element-function": import("../data/features.js").Feature;
        "css-env-function": import("../data/features.js").Feature;
        "css-exclusions": import("../data/features.js").Feature;
        "css-featurequeries": import("../data/features.js").Feature;
        "css-file-selector-button": import("../data/features.js").Feature;
        "css-filter-function": import("../data/features.js").Feature;
        "css-filters": import("../data/features.js").Feature;
        "css-first-letter": import("../data/features.js").Feature;
        "css-first-line": import("../data/features.js").Feature;
        "css-fixed": import("../data/features.js").Feature;
        "css-focus-visible": import("../data/features.js").Feature;
        "css-focus-within": import("../data/features.js").Feature;
        "css-font-palette": import("../data/features.js").Feature;
        "css-font-rendering-controls": import("../data/features.js").Feature;
        "css-font-stretch": import("../data/features.js").Feature;
        "css-gencontent": import("../data/features.js").Feature;
        "css-gradients": import("../data/features.js").Feature;
        "css-grid": import("../data/features.js").Feature;
        "css-grid-animation": import("../data/features.js").Feature;
        "css-hanging-punctuation": import("../data/features.js").Feature;
        "css-has": import("../data/features.js").Feature;
        "css-hyphens": import("../data/features.js").Feature;
        "css-image-orientation": import("../data/features.js").Feature;
        "css-image-set": import("../data/features.js").Feature;
        "css-in-out-of-range": import("../data/features.js").Feature;
        "css-indeterminate-pseudo": import("../data/features.js").Feature;
        "css-initial-letter": import("../data/features.js").Feature;
        "css-initial-value": import("../data/features.js").Feature;
        "css-lch-lab": import("../data/features.js").Feature;
        "css-letter-spacing": import("../data/features.js").Feature;
        "css-line-clamp": import("../data/features.js").Feature;
        "css-logical-props": import("../data/features.js").Feature;
        "css-marker-pseudo": import("../data/features.js").Feature;
        "css-masks": import("../data/features.js").Feature;
        "css-matches-pseudo": import("../data/features.js").Feature;
        "css-math-functions": import("../data/features.js").Feature;
        "css-media-interaction": import("../data/features.js").Feature;
        "css-media-range-syntax": import("../data/features.js").Feature;
        "css-media-resolution": import("../data/features.js").Feature;
        "css-media-scripting": import("../data/features.js").Feature;
        "css-mediaqueries": import("../data/features.js").Feature;
        "css-mixblendmode": import("../data/features.js").Feature;
        "css-motion-paths": import("../data/features.js").Feature;
        "css-namespaces": import("../data/features.js").Feature;
        "css-nesting": import("../data/features.js").Feature;
        "css-not-sel-list": import("../data/features.js").Feature;
        "css-nth-child-of": import("../data/features.js").Feature;
        "css-opacity": import("../data/features.js").Feature;
        "css-optional-pseudo": import("../data/features.js").Feature;
        "css-overflow": import("../data/features.js").Feature;
        "css-overflow-anchor": import("../data/features.js").Feature;
        "css-overflow-overlay": import("../data/features.js").Feature;
        "css-overscroll-behavior": import("../data/features.js").Feature;
        "css-page-break": import("../data/features.js").Feature;
        "css-paged-media": import("../data/features.js").Feature;
        "css-paint-api": import("../data/features.js").Feature;
        "css-placeholder": import("../data/features.js").Feature;
        "css-placeholder-shown": import("../data/features.js").Feature;
        "css-print-color-adjust": import("../data/features.js").Feature;
        "css-read-only-write": import("../data/features.js").Feature;
        "css-rebeccapurple": import("../data/features.js").Feature;
        "css-reflections": import("../data/features.js").Feature;
        "css-regions": import("../data/features.js").Feature;
        "css-relative-colors": import("../data/features.js").Feature;
        "css-repeating-gradients": import("../data/features.js").Feature;
        "css-resize": import("../data/features.js").Feature;
        "css-revert-value": import("../data/features.js").Feature;
        "css-rrggbbaa": import("../data/features.js").Feature;
        "css-scroll-behavior": import("../data/features.js").Feature;
        "css-scroll-timeline": import("../data/features.js").Feature;
        "css-scrollbar": import("../data/features.js").Feature;
        "css-sel2": import("../data/features.js").Feature;
        "css-sel3": import("../data/features.js").Feature;
        "css-selection": import("../data/features.js").Feature;
        "css-shapes": import("../data/features.js").Feature;
        "css-snappoints": import("../data/features.js").Feature;
        "css-sticky": import("../data/features.js").Feature;
        "css-subgrid": import("../data/features.js").Feature;
        "css-supports-api": import("../data/features.js").Feature;
        "css-table": import("../data/features.js").Feature;
        "css-text-align-last": import("../data/features.js").Feature;
        "css-text-box-trim": import("../data/features.js").Feature;
        "css-text-indent": import("../data/features.js").Feature;
        "css-text-justify": import("../data/features.js").Feature;
        "css-text-orientation": import("../data/features.js").Feature;
        "css-text-spacing": import("../data/features.js").Feature;
        "css-textshadow": import("../data/features.js").Feature;
        "css-touch-action": import("../data/features.js").Feature;
        "css-transitions": import("../data/features.js").Feature;
        "css-unicode-bidi": import("../data/features.js").Feature;
        "css-unset-value": import("../data/features.js").Feature;
        "css-variables": import("../data/features.js").Feature;
        "css-when-else": import("../data/features.js").Feature;
        "css-widows-orphans": import("../data/features.js").Feature;
        "css-width-stretch": import("../data/features.js").Feature;
        "css-writing-mode": import("../data/features.js").Feature;
        "css-zoom": import("../data/features.js").Feature;
        "css3-attr": import("../data/features.js").Feature;
        "css3-boxsizing": import("../data/features.js").Feature;
        "css3-colors": import("../data/features.js").Feature;
        "css3-cursors": import("../data/features.js").Feature;
        "css3-cursors-grab": import("../data/features.js").Feature;
        "css3-cursors-newer": import("../data/features.js").Feature;
        "css3-tabsize": import("../data/features.js").Feature;
        currentcolor: import("../data/features.js").Feature;
        devicepixelratio: import("../data/features.js").Feature;
        "extended-system-fonts": import("../data/features.js").Feature;
        flexbox: import("../data/features.js").Feature;
        "flexbox-gap": import("../data/features.js").Feature;
        "font-family-system-ui": import("../data/features.js").Feature;
        "font-feature": import("../data/features.js").Feature;
        "font-loading": import("../data/features.js").Feature;
        "font-unicode-range": import("../data/features.js").Feature;
        fontface: import("../data/features.js").Feature;
        fullscreen: import("../data/features.js").Feature;
        getcomputedstyle: import("../data/features.js").Feature;
        "intrinsic-width": import("../data/features.js").Feature;
        "justify-content-space-evenly": import("../data/features.js").Feature;
        "kerning-pairs-ligatures": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate-override": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-plaintext": import("../data/features.js").Feature;
        "mdn-text-decoration-color": import("../data/features.js").Feature;
        "mdn-text-decoration-line": import("../data/features.js").Feature;
        "mdn-text-decoration-shorthand": import("../data/features.js").Feature;
        "mdn-text-decoration-style": import("../data/features.js").Feature;
        minmaxwh: import("../data/features.js").Feature;
        multibackgrounds: import("../data/features.js").Feature;
        multicolumn: import("../data/features.js").Feature;
        "style-scoped": import("../data/features.js").Feature;
        "svg-css": import("../data/features.js").Feature;
        transforms2d: import("../data/features.js").Feature;
        transforms3d: import("../data/features.js").Feature;
        ttf: import("../data/features.js").Feature;
        "user-select-none": import("../data/features.js").Feature;
        "variable-fonts": import("../data/features.js").Feature;
        "viewport-unit-variants": import("../data/features.js").Feature;
        "viewport-units": import("../data/features.js").Feature;
        wordwrap: import("../data/features.js").Feature;
    } & string)[];
    /**
     * @param {import('postcss').Comment} comment
     * @return {void}
     */
    comment(comment: import('postcss').Comment): void;
    /**
     * @param {import('postcss').Container} node
     * @param {DetectorCallback} callback
     * @return {void}
     */
    node(node: import('postcss').Container, callback: DetectorCallback): void;
    /**
     * @param {import('postcss').Root} node
     * @param {DetectorCallback} callback
     * @return {void}
     */
    process(node: import('postcss').Root, callback: DetectorCallback): void;
}
export type DetectorCallbackArgument = {
    usage: import('postcss').ChildNode;
    feature: keyof {
        outline: import("../data/features.js").Feature;
        "background-attachment": import("../data/features.js").Feature;
        pointer: import("../data/features.js").Feature;
        "flow-root": import("../data/features.js").Feature;
        "font-kerning": import("../data/features.js").Feature;
        "font-smooth": import("../data/features.js").Feature;
        "font-variant-alternates": import("../data/features.js").Feature;
        "font-variant-numeric": import("../data/features.js").Feature;
        "inline-block": import("../data/features.js").Feature;
        "prefers-color-scheme": import("../data/features.js").Feature;
        "prefers-reduced-motion": import("../data/features.js").Feature;
        rem: import("../data/features.js").Feature;
        "run-in": import("../data/features.js").Feature;
        "text-emphasis": import("../data/features.js").Feature;
        "text-stroke": import("../data/features.js").Feature;
        "webkit-user-drag": import("../data/features.js").Feature;
        "border-image": import("../data/features.js").Feature;
        "border-radius": import("../data/features.js").Feature;
        "font-size-adjust": import("../data/features.js").Feature;
        "text-decoration": import("../data/features.js").Feature;
        "object-fit": import("../data/features.js").Feature;
        "pointer-events": import("../data/features.js").Feature;
        "text-overflow": import("../data/features.js").Feature;
        "text-size-adjust": import("../data/features.js").Feature;
        "will-change": import("../data/features.js").Feature;
        "word-break": import("../data/features.js").Feature;
        "alternate-stylesheet": import("../data/features.js").Feature;
        "background-clip-text": import("../data/features.js").Feature;
        "background-img-opts": import("../data/features.js").Feature;
        "background-position-x-y": import("../data/features.js").Feature;
        "background-repeat-round-space": import("../data/features.js").Feature;
        calc: import("../data/features.js").Feature;
        "ch-unit": import("../data/features.js").Feature;
        "css-all": import("../data/features.js").Feature;
        "css-animation": import("../data/features.js").Feature;
        "css-any-link": import("../data/features.js").Feature;
        "css-appearance": import("../data/features.js").Feature;
        "css-at-counter-style": import("../data/features.js").Feature;
        "css-autofill": import("../data/features.js").Feature;
        "css-backdrop-filter": import("../data/features.js").Feature;
        "css-background-offsets": import("../data/features.js").Feature;
        "css-backgroundblendmode": import("../data/features.js").Feature;
        "css-boxdecorationbreak": import("../data/features.js").Feature;
        "css-boxshadow": import("../data/features.js").Feature;
        "css-canvas": import("../data/features.js").Feature;
        "css-caret-color": import("../data/features.js").Feature;
        "css-cascade-layers": import("../data/features.js").Feature;
        "css-case-insensitive": import("../data/features.js").Feature;
        "css-clip-path": import("../data/features.js").Feature;
        "css-color-adjust": import("../data/features.js").Feature;
        "css-color-function": import("../data/features.js").Feature;
        "css-conic-gradients": import("../data/features.js").Feature;
        "css-container-queries": import("../data/features.js").Feature;
        "css-container-queries-style": import("../data/features.js").Feature;
        "css-container-query-units": import("../data/features.js").Feature;
        "css-containment": import("../data/features.js").Feature;
        "css-content-visibility": import("../data/features.js").Feature;
        "css-counters": import("../data/features.js").Feature;
        "css-crisp-edges": import("../data/features.js").Feature;
        "css-cross-fade": import("../data/features.js").Feature;
        "css-default-pseudo": import("../data/features.js").Feature;
        "css-descendant-gtgt": import("../data/features.js").Feature;
        "css-deviceadaptation": import("../data/features.js").Feature;
        "css-dir-pseudo": import("../data/features.js").Feature;
        "css-display-contents": import("../data/features.js").Feature;
        "css-element-function": import("../data/features.js").Feature;
        "css-env-function": import("../data/features.js").Feature;
        "css-exclusions": import("../data/features.js").Feature;
        "css-featurequeries": import("../data/features.js").Feature;
        "css-file-selector-button": import("../data/features.js").Feature;
        "css-filter-function": import("../data/features.js").Feature;
        "css-filters": import("../data/features.js").Feature;
        "css-first-letter": import("../data/features.js").Feature;
        "css-first-line": import("../data/features.js").Feature;
        "css-fixed": import("../data/features.js").Feature;
        "css-focus-visible": import("../data/features.js").Feature;
        "css-focus-within": import("../data/features.js").Feature;
        "css-font-palette": import("../data/features.js").Feature;
        "css-font-rendering-controls": import("../data/features.js").Feature;
        "css-font-stretch": import("../data/features.js").Feature;
        "css-gencontent": import("../data/features.js").Feature;
        "css-gradients": import("../data/features.js").Feature;
        "css-grid": import("../data/features.js").Feature;
        "css-grid-animation": import("../data/features.js").Feature;
        "css-hanging-punctuation": import("../data/features.js").Feature;
        "css-has": import("../data/features.js").Feature;
        "css-hyphens": import("../data/features.js").Feature;
        "css-image-orientation": import("../data/features.js").Feature;
        "css-image-set": import("../data/features.js").Feature;
        "css-in-out-of-range": import("../data/features.js").Feature;
        "css-indeterminate-pseudo": import("../data/features.js").Feature;
        "css-initial-letter": import("../data/features.js").Feature;
        "css-initial-value": import("../data/features.js").Feature;
        "css-lch-lab": import("../data/features.js").Feature;
        "css-letter-spacing": import("../data/features.js").Feature;
        "css-line-clamp": import("../data/features.js").Feature;
        "css-logical-props": import("../data/features.js").Feature;
        "css-marker-pseudo": import("../data/features.js").Feature;
        "css-masks": import("../data/features.js").Feature;
        "css-matches-pseudo": import("../data/features.js").Feature;
        "css-math-functions": import("../data/features.js").Feature;
        "css-media-interaction": import("../data/features.js").Feature;
        "css-media-range-syntax": import("../data/features.js").Feature;
        "css-media-resolution": import("../data/features.js").Feature;
        "css-media-scripting": import("../data/features.js").Feature;
        "css-mediaqueries": import("../data/features.js").Feature;
        "css-mixblendmode": import("../data/features.js").Feature;
        "css-motion-paths": import("../data/features.js").Feature;
        "css-namespaces": import("../data/features.js").Feature;
        "css-nesting": import("../data/features.js").Feature;
        "css-not-sel-list": import("../data/features.js").Feature;
        "css-nth-child-of": import("../data/features.js").Feature;
        "css-opacity": import("../data/features.js").Feature;
        "css-optional-pseudo": import("../data/features.js").Feature;
        "css-overflow": import("../data/features.js").Feature;
        "css-overflow-anchor": import("../data/features.js").Feature;
        "css-overflow-overlay": import("../data/features.js").Feature;
        "css-overscroll-behavior": import("../data/features.js").Feature;
        "css-page-break": import("../data/features.js").Feature;
        "css-paged-media": import("../data/features.js").Feature;
        "css-paint-api": import("../data/features.js").Feature;
        "css-placeholder": import("../data/features.js").Feature;
        "css-placeholder-shown": import("../data/features.js").Feature;
        "css-print-color-adjust": import("../data/features.js").Feature;
        "css-read-only-write": import("../data/features.js").Feature;
        "css-rebeccapurple": import("../data/features.js").Feature;
        "css-reflections": import("../data/features.js").Feature;
        "css-regions": import("../data/features.js").Feature;
        "css-relative-colors": import("../data/features.js").Feature;
        "css-repeating-gradients": import("../data/features.js").Feature;
        "css-resize": import("../data/features.js").Feature;
        "css-revert-value": import("../data/features.js").Feature;
        "css-rrggbbaa": import("../data/features.js").Feature;
        "css-scroll-behavior": import("../data/features.js").Feature;
        "css-scroll-timeline": import("../data/features.js").Feature;
        "css-scrollbar": import("../data/features.js").Feature;
        "css-sel2": import("../data/features.js").Feature;
        "css-sel3": import("../data/features.js").Feature;
        "css-selection": import("../data/features.js").Feature;
        "css-shapes": import("../data/features.js").Feature;
        "css-snappoints": import("../data/features.js").Feature;
        "css-sticky": import("../data/features.js").Feature;
        "css-subgrid": import("../data/features.js").Feature;
        "css-supports-api": import("../data/features.js").Feature;
        "css-table": import("../data/features.js").Feature;
        "css-text-align-last": import("../data/features.js").Feature;
        "css-text-box-trim": import("../data/features.js").Feature;
        "css-text-indent": import("../data/features.js").Feature;
        "css-text-justify": import("../data/features.js").Feature;
        "css-text-orientation": import("../data/features.js").Feature;
        "css-text-spacing": import("../data/features.js").Feature;
        "css-textshadow": import("../data/features.js").Feature;
        "css-touch-action": import("../data/features.js").Feature;
        "css-transitions": import("../data/features.js").Feature;
        "css-unicode-bidi": import("../data/features.js").Feature;
        "css-unset-value": import("../data/features.js").Feature;
        "css-variables": import("../data/features.js").Feature;
        "css-when-else": import("../data/features.js").Feature;
        "css-widows-orphans": import("../data/features.js").Feature;
        "css-width-stretch": import("../data/features.js").Feature;
        "css-writing-mode": import("../data/features.js").Feature;
        "css-zoom": import("../data/features.js").Feature;
        "css3-attr": import("../data/features.js").Feature;
        "css3-boxsizing": import("../data/features.js").Feature;
        "css3-colors": import("../data/features.js").Feature;
        "css3-cursors": import("../data/features.js").Feature;
        "css3-cursors-grab": import("../data/features.js").Feature;
        "css3-cursors-newer": import("../data/features.js").Feature;
        "css3-tabsize": import("../data/features.js").Feature;
        currentcolor: import("../data/features.js").Feature;
        devicepixelratio: import("../data/features.js").Feature;
        "extended-system-fonts": import("../data/features.js").Feature;
        flexbox: import("../data/features.js").Feature;
        "flexbox-gap": import("../data/features.js").Feature;
        "font-family-system-ui": import("../data/features.js").Feature;
        "font-feature": import("../data/features.js").Feature;
        "font-loading": import("../data/features.js").Feature;
        "font-unicode-range": import("../data/features.js").Feature;
        fontface: import("../data/features.js").Feature;
        fullscreen: import("../data/features.js").Feature;
        getcomputedstyle: import("../data/features.js").Feature;
        "intrinsic-width": import("../data/features.js").Feature;
        "justify-content-space-evenly": import("../data/features.js").Feature;
        "kerning-pairs-ligatures": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate-override": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-plaintext": import("../data/features.js").Feature;
        "mdn-text-decoration-color": import("../data/features.js").Feature;
        "mdn-text-decoration-line": import("../data/features.js").Feature;
        "mdn-text-decoration-shorthand": import("../data/features.js").Feature;
        "mdn-text-decoration-style": import("../data/features.js").Feature;
        minmaxwh: import("../data/features.js").Feature;
        multibackgrounds: import("../data/features.js").Feature;
        multicolumn: import("../data/features.js").Feature;
        "style-scoped": import("../data/features.js").Feature;
        "svg-css": import("../data/features.js").Feature;
        transforms2d: import("../data/features.js").Feature;
        transforms3d: import("../data/features.js").Feature;
        ttf: import("../data/features.js").Feature;
        "user-select-none": import("../data/features.js").Feature;
        "variable-fonts": import("../data/features.js").Feature;
        "viewport-unit-variants": import("../data/features.js").Feature;
        "viewport-units": import("../data/features.js").Feature;
        wordwrap: import("../data/features.js").Feature;
    };
    ignore: (keyof {
        outline: import("../data/features.js").Feature;
        "background-attachment": import("../data/features.js").Feature;
        pointer: import("../data/features.js").Feature;
        "flow-root": import("../data/features.js").Feature;
        "font-kerning": import("../data/features.js").Feature;
        "font-smooth": import("../data/features.js").Feature;
        "font-variant-alternates": import("../data/features.js").Feature;
        "font-variant-numeric": import("../data/features.js").Feature;
        "inline-block": import("../data/features.js").Feature;
        "prefers-color-scheme": import("../data/features.js").Feature;
        "prefers-reduced-motion": import("../data/features.js").Feature;
        rem: import("../data/features.js").Feature;
        "run-in": import("../data/features.js").Feature;
        "text-emphasis": import("../data/features.js").Feature;
        "text-stroke": import("../data/features.js").Feature;
        "webkit-user-drag": import("../data/features.js").Feature;
        "border-image": import("../data/features.js").Feature;
        "border-radius": import("../data/features.js").Feature;
        "font-size-adjust": import("../data/features.js").Feature;
        "text-decoration": import("../data/features.js").Feature;
        "object-fit": import("../data/features.js").Feature;
        "pointer-events": import("../data/features.js").Feature;
        "text-overflow": import("../data/features.js").Feature;
        "text-size-adjust": import("../data/features.js").Feature;
        "will-change": import("../data/features.js").Feature;
        "word-break": import("../data/features.js").Feature;
        "alternate-stylesheet": import("../data/features.js").Feature;
        "background-clip-text": import("../data/features.js").Feature;
        "background-img-opts": import("../data/features.js").Feature;
        "background-position-x-y": import("../data/features.js").Feature;
        "background-repeat-round-space": import("../data/features.js").Feature;
        calc: import("../data/features.js").Feature;
        "ch-unit": import("../data/features.js").Feature;
        "css-all": import("../data/features.js").Feature;
        "css-animation": import("../data/features.js").Feature;
        "css-any-link": import("../data/features.js").Feature;
        "css-appearance": import("../data/features.js").Feature;
        "css-at-counter-style": import("../data/features.js").Feature;
        "css-autofill": import("../data/features.js").Feature;
        "css-backdrop-filter": import("../data/features.js").Feature;
        "css-background-offsets": import("../data/features.js").Feature;
        "css-backgroundblendmode": import("../data/features.js").Feature;
        "css-boxdecorationbreak": import("../data/features.js").Feature;
        "css-boxshadow": import("../data/features.js").Feature;
        "css-canvas": import("../data/features.js").Feature;
        "css-caret-color": import("../data/features.js").Feature;
        "css-cascade-layers": import("../data/features.js").Feature;
        "css-case-insensitive": import("../data/features.js").Feature;
        "css-clip-path": import("../data/features.js").Feature;
        "css-color-adjust": import("../data/features.js").Feature;
        "css-color-function": import("../data/features.js").Feature;
        "css-conic-gradients": import("../data/features.js").Feature;
        "css-container-queries": import("../data/features.js").Feature;
        "css-container-queries-style": import("../data/features.js").Feature;
        "css-container-query-units": import("../data/features.js").Feature;
        "css-containment": import("../data/features.js").Feature;
        "css-content-visibility": import("../data/features.js").Feature;
        "css-counters": import("../data/features.js").Feature;
        "css-crisp-edges": import("../data/features.js").Feature;
        "css-cross-fade": import("../data/features.js").Feature;
        "css-default-pseudo": import("../data/features.js").Feature;
        "css-descendant-gtgt": import("../data/features.js").Feature;
        "css-deviceadaptation": import("../data/features.js").Feature;
        "css-dir-pseudo": import("../data/features.js").Feature;
        "css-display-contents": import("../data/features.js").Feature;
        "css-element-function": import("../data/features.js").Feature;
        "css-env-function": import("../data/features.js").Feature;
        "css-exclusions": import("../data/features.js").Feature;
        "css-featurequeries": import("../data/features.js").Feature;
        "css-file-selector-button": import("../data/features.js").Feature;
        "css-filter-function": import("../data/features.js").Feature;
        "css-filters": import("../data/features.js").Feature;
        "css-first-letter": import("../data/features.js").Feature;
        "css-first-line": import("../data/features.js").Feature;
        "css-fixed": import("../data/features.js").Feature;
        "css-focus-visible": import("../data/features.js").Feature;
        "css-focus-within": import("../data/features.js").Feature;
        "css-font-palette": import("../data/features.js").Feature;
        "css-font-rendering-controls": import("../data/features.js").Feature;
        "css-font-stretch": import("../data/features.js").Feature;
        "css-gencontent": import("../data/features.js").Feature;
        "css-gradients": import("../data/features.js").Feature;
        "css-grid": import("../data/features.js").Feature;
        "css-grid-animation": import("../data/features.js").Feature;
        "css-hanging-punctuation": import("../data/features.js").Feature;
        "css-has": import("../data/features.js").Feature;
        "css-hyphens": import("../data/features.js").Feature;
        "css-image-orientation": import("../data/features.js").Feature;
        "css-image-set": import("../data/features.js").Feature;
        "css-in-out-of-range": import("../data/features.js").Feature;
        "css-indeterminate-pseudo": import("../data/features.js").Feature;
        "css-initial-letter": import("../data/features.js").Feature;
        "css-initial-value": import("../data/features.js").Feature;
        "css-lch-lab": import("../data/features.js").Feature;
        "css-letter-spacing": import("../data/features.js").Feature;
        "css-line-clamp": import("../data/features.js").Feature;
        "css-logical-props": import("../data/features.js").Feature;
        "css-marker-pseudo": import("../data/features.js").Feature;
        "css-masks": import("../data/features.js").Feature;
        "css-matches-pseudo": import("../data/features.js").Feature;
        "css-math-functions": import("../data/features.js").Feature;
        "css-media-interaction": import("../data/features.js").Feature;
        "css-media-range-syntax": import("../data/features.js").Feature;
        "css-media-resolution": import("../data/features.js").Feature;
        "css-media-scripting": import("../data/features.js").Feature;
        "css-mediaqueries": import("../data/features.js").Feature;
        "css-mixblendmode": import("../data/features.js").Feature;
        "css-motion-paths": import("../data/features.js").Feature;
        "css-namespaces": import("../data/features.js").Feature;
        "css-nesting": import("../data/features.js").Feature;
        "css-not-sel-list": import("../data/features.js").Feature;
        "css-nth-child-of": import("../data/features.js").Feature;
        "css-opacity": import("../data/features.js").Feature;
        "css-optional-pseudo": import("../data/features.js").Feature;
        "css-overflow": import("../data/features.js").Feature;
        "css-overflow-anchor": import("../data/features.js").Feature;
        "css-overflow-overlay": import("../data/features.js").Feature;
        "css-overscroll-behavior": import("../data/features.js").Feature;
        "css-page-break": import("../data/features.js").Feature;
        "css-paged-media": import("../data/features.js").Feature;
        "css-paint-api": import("../data/features.js").Feature;
        "css-placeholder": import("../data/features.js").Feature;
        "css-placeholder-shown": import("../data/features.js").Feature;
        "css-print-color-adjust": import("../data/features.js").Feature;
        "css-read-only-write": import("../data/features.js").Feature;
        "css-rebeccapurple": import("../data/features.js").Feature;
        "css-reflections": import("../data/features.js").Feature;
        "css-regions": import("../data/features.js").Feature;
        "css-relative-colors": import("../data/features.js").Feature;
        "css-repeating-gradients": import("../data/features.js").Feature;
        "css-resize": import("../data/features.js").Feature;
        "css-revert-value": import("../data/features.js").Feature;
        "css-rrggbbaa": import("../data/features.js").Feature;
        "css-scroll-behavior": import("../data/features.js").Feature;
        "css-scroll-timeline": import("../data/features.js").Feature;
        "css-scrollbar": import("../data/features.js").Feature;
        "css-sel2": import("../data/features.js").Feature;
        "css-sel3": import("../data/features.js").Feature;
        "css-selection": import("../data/features.js").Feature;
        "css-shapes": import("../data/features.js").Feature;
        "css-snappoints": import("../data/features.js").Feature;
        "css-sticky": import("../data/features.js").Feature;
        "css-subgrid": import("../data/features.js").Feature;
        "css-supports-api": import("../data/features.js").Feature;
        "css-table": import("../data/features.js").Feature;
        "css-text-align-last": import("../data/features.js").Feature;
        "css-text-box-trim": import("../data/features.js").Feature;
        "css-text-indent": import("../data/features.js").Feature;
        "css-text-justify": import("../data/features.js").Feature;
        "css-text-orientation": import("../data/features.js").Feature;
        "css-text-spacing": import("../data/features.js").Feature;
        "css-textshadow": import("../data/features.js").Feature;
        "css-touch-action": import("../data/features.js").Feature;
        "css-transitions": import("../data/features.js").Feature;
        "css-unicode-bidi": import("../data/features.js").Feature;
        "css-unset-value": import("../data/features.js").Feature;
        "css-variables": import("../data/features.js").Feature;
        "css-when-else": import("../data/features.js").Feature;
        "css-widows-orphans": import("../data/features.js").Feature;
        "css-width-stretch": import("../data/features.js").Feature;
        "css-writing-mode": import("../data/features.js").Feature;
        "css-zoom": import("../data/features.js").Feature;
        "css3-attr": import("../data/features.js").Feature;
        "css3-boxsizing": import("../data/features.js").Feature;
        "css3-colors": import("../data/features.js").Feature;
        "css3-cursors": import("../data/features.js").Feature;
        "css3-cursors-grab": import("../data/features.js").Feature;
        "css3-cursors-newer": import("../data/features.js").Feature;
        "css3-tabsize": import("../data/features.js").Feature;
        currentcolor: import("../data/features.js").Feature;
        devicepixelratio: import("../data/features.js").Feature;
        "extended-system-fonts": import("../data/features.js").Feature;
        flexbox: import("../data/features.js").Feature;
        "flexbox-gap": import("../data/features.js").Feature;
        "font-family-system-ui": import("../data/features.js").Feature;
        "font-feature": import("../data/features.js").Feature;
        "font-loading": import("../data/features.js").Feature;
        "font-unicode-range": import("../data/features.js").Feature;
        fontface: import("../data/features.js").Feature;
        fullscreen: import("../data/features.js").Feature;
        getcomputedstyle: import("../data/features.js").Feature;
        "intrinsic-width": import("../data/features.js").Feature;
        "justify-content-space-evenly": import("../data/features.js").Feature;
        "kerning-pairs-ligatures": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-isolate-override": import("../data/features.js").Feature;
        "mdn-css-unicode-bidi-plaintext": import("../data/features.js").Feature;
        "mdn-text-decoration-color": import("../data/features.js").Feature;
        "mdn-text-decoration-line": import("../data/features.js").Feature;
        "mdn-text-decoration-shorthand": import("../data/features.js").Feature;
        "mdn-text-decoration-style": import("../data/features.js").Feature;
        minmaxwh: import("../data/features.js").Feature;
        multibackgrounds: import("../data/features.js").Feature;
        multicolumn: import("../data/features.js").Feature;
        "style-scoped": import("../data/features.js").Feature;
        "svg-css": import("../data/features.js").Feature;
        transforms2d: import("../data/features.js").Feature;
        transforms3d: import("../data/features.js").Feature;
        ttf: import("../data/features.js").Feature;
        "user-select-none": import("../data/features.js").Feature;
        "variable-fonts": import("../data/features.js").Feature;
        "viewport-unit-variants": import("../data/features.js").Feature;
        "viewport-units": import("../data/features.js").Feature;
        wordwrap: import("../data/features.js").Feature;
    } & string)[];
};
export type DetectorCallback = (result: DetectorCallbackArgument) => any;
